@@ -26,7 +26,7 @@ class Neo4jHelper:
         """
         if isinstance(pool, str):
 
-            self.pool, self.dialect = options.database[pool]
+            self.pool, self.conn_info = options.database[pool]
             self.pool = self.pool.session(database=pool, default_access_mode=access)
         else:
             self.pool = pool
