@@ -6,7 +6,10 @@ def get_value_from_dict(data: dict, key: str = None):
     if key:
         key_list = key.split(".")
         for k in key_list:
-            value = value.get(k)
+            if not isinstance(value, dict):
+                break
+            else:
+                value = value.get(k)
     return value
 
 
