@@ -102,8 +102,13 @@ def sync_get(path, params=None, base_url=None, result_type="json", pack=False, *
         }})
     elif project_name:
         kwargs["headers"].update({"Project-Name": project_name})
-    res = requests.get(base_url + path, params=params, **kwargs)
-    res.close()
+    s = requests.session()
+    try:
+        res = s.get(base_url + path, params=params, **kwargs)
+    except Exception as e:
+        raise e
+    finally:
+        s.close()
     if result_type == "json":
         res = res.json()
         if not pack:
@@ -126,24 +131,29 @@ def sync_post(path, data=None,
     if not base_url:
         base_url = tornado.options.options.data_server
     flag = kwargs.pop("flag", True)
-    if flag:
-        if not kwargs.get("headers"):
-            kwargs.update({"headers": {
-                "Content-Type": "application/json",
-                "Project-Name": project_name
-            }})
+    s = requests.session()
+    try:
+        if flag:
+            if not kwargs.get("headers"):
+                kwargs.update({"headers": {
+                    "Content-Type": "application/json",
+                    "Project-Name": project_name
+                }})
+            else:
+                kwargs["headers"].update({"Project-Name": project_name})
+            res = s.post(base_url + path, json=data, **kwargs)
         else:
-            kwargs["headers"].update({"Project-Name": project_name})
-        res = requests.post(base_url + path, json=data, **kwargs)
-    else:
-        if not kwargs.get("headers"):
-            kwargs.update({"headers": {
-                "Project-Name": project_name
-            }})
-        else:
-            kwargs["headers"].update({"Project-Name": project_name})
-        res = requests.post(base_url + path, data=data, **kwargs)
-    res.close()
+            if not kwargs.get("headers"):
+                kwargs.update({"headers": {
+                    "Project-Name": project_name
+                }})
+            else:
+                kwargs["headers"].update({"Project-Name": project_name})
+            res = s.post(base_url + path, data=data, **kwargs)
+    except Exception as e:
+        raise e
+    finally:
+        s.close()
     if result_type == "json":
         res = res.json()
         if not pack:
